==> phpbb3_3.0.12.orig-l10n-hr.tar.xz: croatian_1_0_5/language/hr/search_ignore_words.php <==
<?php
/**
*
* ucp.php [Croatian]
*
* @package language
* @version $Id: $
* @copyright (c) 2011 phpBB Group
* @author 2011-11-18 - phpbb.com.hr
* @author 2003-2008 - Ančica Sečan
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
   exit;
}

$words = array(
'a',
'ajme',
'ako',
'ali',
'bar',
'barem',
'bas',
'baš',
'bez',
'bi',
'bih',
'bila',
'bile',
'bili',
'bilo',
'bio',
'bismo',
'biste',
'bit',
'biti',
'bolje',
'bravo',
'bude',
'budem',
'budemo',
'budes',
'budeš',
'budete',
'budu',
'ce',
'cekaj',
'cemo',
'cemu',
'ces',
'cete',
'cu',
'čekaj',
'čemu',
'će',
'ćemo',
'ćeš',
'ćete',
'ću',
'da',
'daj',
'dakle',
'dalje',
'dam',
'davno',
'do',
'dobar',
'dobila',
'dobile',
'dobili',
'dobio',
'dobra',
'dobre',
'dobri',
'dobro',
'dolje',
'dosta',
'e',
'eno',
'eto',
'evo',
'ga',
'gdje',
'gle',
'gore',
'hvala',
'i',
'iako',
'ide',
'idem',
'idemo',
'ides',
'ideš',
'idete',
'idu',
'igdje',
'ih',
'ikada',
'ikako',
'ikoliko',
'ili',
'ima',
'imaju',
'imam',
'imamo',
'imas',
'imaš',
'imate',
'inace',
'inače',
'iole',
'itko',
'iza',
'izgleda',
'ja',
'jako',
'je',
'jedino',
'jedva',
'jer',
'jesam',
'jesi',
'jesmo',
'jeste',
'jesu',
'još',
'ju',
'kad',
'kada',
'kak',
'kako',
'kamo',
'kao',
'kasnije',
'kaze',
'kazem',
'kazi',
'kaže',
'kažem',
'kaži',
'koja',
'koje',
'kojeg',
'kojem',
'koji',
'kojima',
'kojoj',
'koju',
'koliko',
'kratko',
'kriv',
'kriva',
'krivi',
'krivo',
'krivog',
'krivoj',
'krivom',
'krivu',
'lako',
'lijepo',
'loš',
'loša',
'loše',
'mala',
'malen',
'malena',
'maleni',
'maleno',
'malenog',
'malenu',
'mali',
'malo',
'malog',
'malu',
'manje',
'me',
'mene',
'meni',
'mi',
'misle',
'mislila',
'mislile',
'mislili',
'mislim',
'mislimo',
'mislio',
'mislis',
'misliš',
'mislite',
'mogao',
'mogla',
'mogle',
'mogli',
'mogu',
'moj',
'moja',
'moje',
'mojem',
'moji',
'mojima',
'mojoj',
'moju',
'molim',
'mora',
'moraju',
'moram',
'moramo',
'moras',
'moraš',
'morate',
'mozda',
'moze',
'mozemo',
'mozes',
'mozete',
'možda',
'može',
'možemo',
'možeš',
'možete',
'na',
'nad',
'nakon',
'nama',
'naravno',
'nas',
'nasa',
'nase',
'nasi',
'naš',
'naša',
'naše',
'naši',
'ne',
'nece',
'necemo',
'neces',
'necete',
'necu',
'neće',
'nećemo',
'nećeš',
'nećete',
'neću',
'nedaj',
'nedam',
'negdje',
'nego',
'nek',
'neka',
'nekako',
'neke',
'neki',
'neko',
'nekoliko',
'nema',
'nemaju',
'nemam',
'nemamo',
'nemas',
'nemaš',
'nemate',
'nemati',
'nemoj',
'nešto',
'netko',
'ni',
'nigdje',
'nije',
'nijednom',
'nikad',
'nikada',
'nikako',
'nikoliko',
'nikome',
'nisam',
'nisi',
'nismo',
'niste',
'nisu',
'ništa',
'niti',
'nitko',
'nje',
'njega',
'njemu',
'njih',
'njima',
'njoj',
'nju',
'o',
'od',
'odgovor',
'odmah',
'on',
'ona',
'onaj',
'onako',
'onda',
'one',
'oni',
'ono',
'onoliko',
'opet',
'osim',
'ova',
'ovaj',
'ovak',
'ovako',
'ovo',
'ovoliko',
'pa',
'pitanje',
'po',
'pobogu',
'pod',
'poput',
'poradi',
'pored',
'poslije',
'prava',
'pravi',
'pravo',
'pravoj',
'pravom',
'preko',
'prema',
'pri',
'prije',
'problem',
'problema',
'problemi',
'puno',
'put',
'puta',
'radi',
'reci',
'rekao',
'rekla',
'rekle',
'rekli',
'ružno',
's',
'sa',
'sad',
'sada',
'sam',
'sama',
'same',
'sami',
'samo',
'se',
'sebe',
'si',
'sigurno',
'skoro',
'smo',
'stalno',
'ste',
'stoga',
'stvarno',
'su',
'super',
'svaka',
'svake',
'svaki',
'svako',
'sve',
'svekoliko',
'svi',
'svih',
'svima',
'svo',
'svoj',
'svoja',
'svoje',
'svoji',
'što',
'ta',
'tada',
'taj',
'tak',
'tako',
'takoder',
'također',
'tamo',
'te',
'tebe',
'tebi',
'tek',
'tesko',
'teško',
'ti',
'tice',
'tiče',
'tim',
'time',
'tko',
'to',
'tog',
'toliko',
'tom',
'tome',
'treba',
'trebam',
'trebamo',
'trebas',
'trebaš',
'tu',
'tvoj',
'tvoja',
'tvoje',
'u',
'uglavnom',
'unutra',
'uopce',
'uopće',
'upravo',
'uskoro',
'uvijek',
'valjda',
'van',
'vani',
'vas',
'vasa',
'vase',
'vasi',
'vaš',
'vaša',
'vaše',
'vaši',
'vec',
'već',
'velik',
'velika',
'velike',
'veliki',
'veliko',
'velikog',
'veliku',
'vi',
'više',
'vrlo',
'za',
'zanima',
'zar',
'zasto',
'zašto',
'zato',
'zbog',
'znam',
'znas',
'znaš',
'žao',
);
?>

==> phpbb3_3.0.14.orig-l10n-hr.tar.xz: croatian_3_0_13/language/hr/search_ignore_words.php <==
<?php
/**
*
* search_ignore_words [Croatian]
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * CONTRIBUTORS - START
*
 *
  * ANČI - START
 * <NE izbrisuj i NE mijenjaj!>
* <!-- Danas će biti toplo i sunčano. -->
* @author Croatian language pack [Hrvatski jezični paket] (c) 2003-3003 Ančica Sečan
* http://ancica.sunceko.net
* <!-- Danas će biti toplo i sunčano. -->
* Ovaj prijevod, s engleskog [originalna verzija] na hrvatski,
* u potpunosti, napravila je Ančica Sečan.
* U kompletu, s prijevodom, dolaze i lokalizirane sličke.
* <!-- Danas će biti toplo i sunčano. -->
 * </NE izbrisuj i NE mijenjaj!>
  *  ANČI - END
 *
*
 * CONTRIBUTORS - END
*
*/
if (!defined('IN_PHPBB'))
{
exit;
}
$words = array(
'a',
'ajme',
'ako',
'ali',
'bar',
'barem',
'bas',
'baš',
'bez',
'bi',
'bih',
'bila',
'bile',
'bili',
'bilo',
'bio',
'bismo',
'biste',
'bit',
'biti',
'bolje',
'bravo',
'bude',
'budem',
'budemo',
'budes',
'budeš',
'budete',
'budu',
'ce',
'cekaj',
// <!-- Kocka je hičena! -->
'cemo',
'cemu',
'ces',
'cete',
'cu',
'čekaj',
'čemu',
'će',
'ćemo',
'ćeš',
'ćete',
'ću',
'da',
'daj',
'dakle',
'dalje',
'dam',
'davno',
'do',
'dobar',
'dobila',
'dobile',
'dobili',
'dobio',
'dobra',
'dobre',
'dobri',
'dobro',
'dolje',
'dosta',
'e',
'eno',
'eto',
'evo',
'ga',
'gdje',
'gle',
'gore',
'hvala',
'i',
'iako',
'ide',
'idem',
'idemo',
'ides',
'ideš',
'idete',
'idu',
'igdje',
'ih',
'ikada',
'ikako',
'ikoliko',
'ili',
'ima',
'imaju',
'imam',
'imamo',
'imas',
'imaš',
'imate',
'inace',
'inače',
'iole',
'itko',
'iza',
'izgleda',
'ja',
'jako',
'je',
'jedino',
'jedva',
'jer',
'jesam',
'jesi',
'jesmo',
'jeste',
'jesu',
'još',
'ju',
'kad',
'kada',
'kak',
'kako',
'kamo',
'kao',
'kasnije',
'kaze',
'kazem',
'kazi',
'kaže',
'kažem',
'kaži',
'koja',
'koje',
'kojeg',
'kojem',
'koji',
'kojima',
'kojoj',
'koju',
'koliko',
'kratko',
'kriv',
'kriva',
'krivi',
'krivo',
'krivog',
'krivoj',
'krivom',
'krivu',
'lako',
'lijepo',
'loš',
'loša',
'loše',
'mala',
'malen',
'malena',
'maleni',
'maleno',
'malenog',
'malenu',
'mali',
'malo',
'malog',
'malu',
'manje',
'me',
'mene',
'meni',
'mi',
'misle',
'mislila',
'mislile',
'mislili',
'mislim',
'mislimo',
'mislio',
'mislis',
'misliš',
'mislite',
'mogao',
'mogla',
'mogle',
'mogli',
'mogu',
'moj',
'moja',
'moje',
'mojem',
'moji',
'mojima',
'mojoj',
'moju',
'molim',
'mora',
'moraju',
'moram',
'moramo',
'moras',
'moraš',
'morate',
'mozda',
'moze',
'mozemo',
'mozes',
'mozete',
'možda',
'može',
'možemo',
'možeš',
'možete',
'na',
'nad',
'nakon',
'nama',
'naravno',
'nas',
'nasa',
'nase',
'nasi',
'naš',
'naša',
'naše',
'naši',
'ne',
'nece',
'necemo',
'neces',
'necete',
'necu',
'neće',
'nećemo',
'nećeš',
'nećete',
'neću',
'nedaj',
'nedam',
'negdje',
'nego',
'nek',
'neka',
'nekako',
'neke',
'neki',
'neko',
'nekoliko',
'nema',
'nemaju',
'nemam',
'nemamo',
'nemas',
'nemaš',
'nemate',
'nemati',
'nemoj',
'nešto',
'netko',
'ni',
'nigdje',
'nije',
'nijednom',
'nikad',
'nikada',
'nikako',
'nikoliko',
'nikome',
'nisam',
'nisi',
'nismo',
'niste',
'nisu',
'ništa',
'niti',
'nitko',
'nje',
'njega',
'njemu',
'njih',
'njima',
'njoj',
'nju',
'o',
'od',
'odgovor',
'odmah',
'on',
'ona',
'onaj',
'onako',
'onda',
'one',
'oni',
'ono',
'onoliko',
'opet',
'osim',
'ova',
'ovaj',
'ovak',
'ovako',
'ovo',
'ovoliko',
'pa',
'pitanje',
'po',
'pobogu',
'pod',
'poput',
'poradi',
'pored',
'poslije',
'prava',
'pravi',
'pravo',
'pravoj',
'pravom',
'preko',
'prema',
'pri',
'prije',
'problem',
'problema',
'problemi',
'puno',
'put',
'puta',
'radi',
'reci',
'rekao',
'rekla',
'rekle',
'rekli',
'ružno',
's',
'sa',
'sad',
'sada',
'sam',
'sama',
'same',
'sami',
'samo',
'se',
'sebe',
'si',
'sigurno',
'skoro',
'smo',
'stalno',
'ste',
'stoga',
'stvarno',
'su',
'super',
'svaka',
'svake',
'svaki',
'svako',
'sve',
'svekoliko',
'svi',
'svih',
'svima',
'svo',
'svoj',
'svoja',
'svoje',
'svoji',
'što',
'ta',
'tada',
'taj',
'tak',
'tako',
'takoder',
'također',
'tamo',
'te',
'tebe',
'tebi',
'tek',
'tesko',
'teško',
'ti',
'tice',
'tiče',
'tim',
'time',
'tko',
'to',
'tog',
'toliko',
'tom',
'tome',
'treba',
'trebam',
'trebamo',
'trebas',
'trebaš',
'tu',
'tvoj',
'tvoja',
'tvoje',
'u',
'uglavnom',
'unutra',
'uopce',
'uopće',
'upravo',
'uskoro',
'uvijek',
'valjda',
'van',
'vani',
'vas',
'vasa',
'vase',
'vasi',
'vaš',
'vaša',
'vaše',
'vaši',
'vec',
'već',
'velik',
'velika',
'velike',
'veliki',
'veliko',
'velikog',
'veliku',
'vi',
'više',
'vrlo',
'za',
'zanima',
'zar',
'zasto',
'zašto',
'zato',
'zbog',
'znam',
'znas',
'znaš',
'žao',
);
?>
